@@ -9,10 +9,8 @@ import math
 class plist:
     '''Список для простої побудови поліномів: індекс - показник степеня, значення - коефіцієнт'''
     def __init__(self, *els):
-        if type(*els) in (list, tuple):
-            self.lst = list(*els)
 
-        self.lst = [*els]
+        self.lst = list(*els)
 
     def __setitem__(self, key, value):
         while True:
